# Fact Sheet Fields
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/fact-sheet-fields#overview)
  * [Configuring Fields](https://help.sap.com/docs/leanix/ea/fact-sheet-fields#configuring-fields)
  * [Field Types](https://help.sap.com/docs/leanix/ea/fact-sheet-fields#field-types)
  * [Field Width](https://help.sap.com/docs/leanix/ea/fact-sheet-fields#field-width)
  * [Adding a Custom Field](https://help.sap.com/docs/leanix/ea/fact-sheet-fields#adding-a-custom-field)
  * [Deleting Fields and Field Values](https://help.sap.com/docs/leanix/ea/fact-sheet-fields#deleting-fields-and-field-values)
  * [Showing Fields in Views](https://help.sap.com/docs/leanix/ea/fact-sheet-fields#showing-fields-in-views)
  * [Showing Fields in Filters](https://help.sap.com/docs/leanix/ea/fact-sheet-fields#showing-fields-in-filters)


View all
Fact sheet fields are designed for storing information on specific data points. You can configure existing fields and create custom ones.
